<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Login Page</title>
    <script src="https://cdn.tailwindcss.com"></script>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <script>
        function togglePasswordVisibility() {
            const passwordInput = document.getElementById("password");
            const eyeIcon = document.getElementById("eye-icon");
            const eyeSlashIcon = document.getElementById("eye-slash-icon");

            if (passwordInput.type === "password") {
                passwordInput.type = "text";
                eyeIcon.classList.remove("hidden");
                eyeSlashIcon.classList.add("hidden");
            } else {
                passwordInput.type = "password";
                eyeIcon.classList.add("hidden");
                eyeSlashIcon.classList.remove("hidden");
            }
        }
    </script>
</head>

<body>
    <div class="flex items-center justify-center h-screen">
        <div class="flex flex-wrap md:flex-nowrap w-90% h-90% bg-white rounded-lg overflow-hidden">
            <!-- Image Section -->
            <div class="hidden md:block md:w-1/2">
                <img src="login-image.jpeg" alt="Login Image" class="w-full h-full object-cover">
            </div>

            <!-- Content Section -->
            <div class="w-full md:w-1/2 p-8">
                <div class="justify-center items-center my-16 ml-28">
                    <h2 class="text-3xl font-semibold text-gray-800 mb-6 text-center">Welcome Back!</h2>
                    <p class="text-gray-600 mb-8 text-center">Please login to your account</p>

                    <form id="loginForm" class="space-y-6">
                        <!-- Email Field -->
                        <div class="relative">
                            <input type="email" id="email" name="email" placeholder="Enter your email"
                                class="w-full px-4 py-2 pl-10 border border-gray-300 rounded-lg focus:outline-none focus:ring-2 focus:ring-[#683ba9]">
                            <span class="absolute inset-y-0 left-3 flex items-center text-gray-400">
                                <i class="fas fa-envelope" id="fasfaenvelope"></i>
                            </span>
                            <p id="email-error" class="text-red-500 text-sm mt-1 hidden">Fill this field</p>
                        </div>

                        <!-- Password Field -->
                        <div class="relative">
                            <input type="password" id="password" name="password" placeholder="Enter your password"
                                class="w-full px-4 py-2 pl-10 border border-gray-300 rounded-lg focus:outline-none focus:ring-2 focus:ring-[#683ba9]">
                            <span class="absolute inset-y-0 left-3 flex items-center text-gray-400">
                                <i class="fas fa-lock" id="fasfalock"></i>
                            </span>
                            <button type="button" class="absolute inset-y-0 right-3 flex items-center text-gray-400"
                                onclick="togglePasswordVisibility()">
                                <i id="eye-icon" class="fas fa-eye hidden"></i>
                                <i id="eye-slash-icon" class="fas fa-eye-slash"></i>
                            </button>
                            <p id="password-error" class="text-red-500 text-sm mt-1 hidden">Fill this field</p>
                        </div>

                        <!-- Submit Button -->
                        <button type="button" id="loginBtn"
                            class="w-full bg-[#735290] text-white py-2 px-4 rounded-lg hover:bg-[#735290] transition">Login
                        </button>
                    </form>

                    <!-- Error message container -->
                    <div id="error-message"
                        class="fixed top-4 right-4 bg-red-500 text-white px-4 py-2 rounded shadow-lg hidden">
                        Entered Email or Password is Incorrect
                    </div>

<!-- JavaScript for AJAX request and validation -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<script>
$(document).ready(function() {
    $("#loginBtn").click(function() {
        let email = $("#email").val().trim();
        let password = $("#password").val().trim();
        let emailError = $("#email-error");
        let passwordError = $("#password-error");
        let emailField = $("#email");
        let passwordField = $("#password");
        let fasEnvelope = $("#fasfaenvelope");
        let fasLock = $("#fasfalock");
        let eyeIcon = $("#eye-icon");
        let eyeSlashIcon = $("#eye-slash-icon")

        let isValid = true;

        // Email validation
        if (email === "") {
            emailField.addClass("border-red-500");
            emailError.removeClass("hidden");
            fasEnvelope.css("margin-bottom", "16px");
            isValid = false;
        } else {
            emailField.removeClass("border-red-500");
            emailError.addClass("hidden");
            fasEnvelope.css("margin-bottom", "0px");

        }

        // Password validation
        if (password === "") {
            passwordField.addClass("border-red-500");
            passwordError.removeClass("hidden");
            fasLock.css("margin-bottom", "16px");
            eyeIcon.css("margin-bottom", "16px");
            eyeSlashIcon.css("margin-bottom", "16px");

            isValid = false;
        } else {
            passwordField.removeClass("border-red-500");
            passwordError.addClass("hidden");
            fasLock.css("margin-bottom", "0px");
            eyeIcon.css("margin-bottom", "0px");
            eyeSlashIcon.css("margin-bottom", "0px");


        }

        if (isValid) {
            // Send AJAX request
            $.ajax({
                url: "login_verification.php",
                type: "POST",
                data: { email: email, password: password },
                success: function(response) {
                    if (response === "success") {
                        window.location.href = "../admin-page.php"; // Redirect on success
                    } else {
                        showErrorMessage();
                    }
                }
            });
        }
    });
});

// Password visibility toggle
function togglePasswordVisibility() {
    let passwordField = document.getElementById("password");
    let eyeIcon = document.getElementById("eye-icon");
    let eyeSlashIcon = document.getElementById("eye-slash-icon");

    if (passwordField.type === "password") {
        passwordField.type = "text";
        eyeIcon.classList.remove("hidden");
        eyeSlashIcon.classList.add("hidden");
    } else {
        passwordField.type = "password";
        eyeIcon.classList.add("hidden");
        eyeSlashIcon.classList.remove("hidden");
    }
}

// Show error message for incorrect credentials
function showErrorMessage() {
    let errorMessage = $("#error-message");
    errorMessage.removeClass("hidden");

    setTimeout(() => {
        errorMessage.addClass("hidden");
    }, 3000); // Hide after 3 seconds
}
</script>

                </div>
            </div>
        </div>
    </div>
</body>

</html>